import QtQuick 1.1

Page {
    id: page0

    property int discountValue: 5;
    onDiscountValueChanged: {
        discountSlider.value = discountValue
    }

    function toFixed(value, precision) {
        var power = Math.pow(10, precision || 0);
        return Math.round(value * power) / power;
    }

    Column {
        anchors.fill: parent

        Bar {
            id: topBar
            Label {
                anchors.left: parent.left;
                anchors.leftMargin: units.gu(1)
                anchors.verticalCenter: parent.verticalCenter

                text: qsTr("Good Discount")
                font.pixelSize: units.gu(4)
                font.bold: true
                width: parent.width
                color: "white"
            }
        }

        Rectangle {
            width: parent.width
            height: parent.height - menuRect.height - topBar.height
            color: "#EEEEEE"
            clip: true

            Flickable {
                id: flickableView

                anchors.fill: parent
                anchors.margins: units.gu(1)

                contentWidth: parent.width
                contentHeight: mainContent.height

                flickableDirection: Flickable.VerticalFlick

                Column {
                    id: mainContent
                    width: parent.width - units.gu(2)
                    spacing: units.gu(1)

                    Label {
                        text: qsTr("Price:")
                        font.pixelSize: units.gu(4)
                    }

                    TextField {
                        id: priceTextField
                        maximumLength: 15
                        height: units.gu(6)
                        width: parent.width
                        font.pixelSize: units.gu(4)
                        inputMethodHints: Qt.ImhFormattedNumbersOnly
                        validator: DoubleValidator{bottom: 0; decimals: 2; notation: DoubleValidator.StandardNotation}
                    }

                    Label {
                        text: qsTr("Discount in percents:")
                        font.pixelSize: units.gu(4)
                    }

                    TextField {
                        id: discountTextField
                        text: discountValue
                        height: units.gu(6)
                        width: units.gu(12)
                        font.pixelSize: units.gu(4)

                        maximumLength: 15
                        inputMethodHints: Qt.ImhDigitsOnly
                        validator: IntValidator {bottom: 0; top: 100}
                        onTextChanged: {
                            discountValue = parseInt(discountTextField.text)
                        }

                        Label {
                            id: percentLabel
                            text: qsTr("%")
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter
                            font.pixelSize: units.gu(4)
                        }
                    }

                    Slider {
                        id: discountSlider
                        width: parent.width
                        stepSize: 1
                        minimumValue: 0
                        maximumValue: 100
                        value: discountValue
                        onValueChanged: discountValue = value
                        onPressed: flickableView.interactive = false
                        onReleased: flickableView.interactive = true
                    }

                    Row {
                        width: parent.width
                        spacing: units.gu(1)
                        Button { text: "-5%"; onClicked: discountValue = 0 > discountValue-5 ? 0 : discountValue - 5;  }
                        Button { text: "-1%"; onClicked: discountValue = 0 > discountValue-1 ? 0 : discountValue - 1; }
                        Button { text: "+1%"; onClicked: discountValue = 100 < discountValue+1 ? 100 : discountValue + 1; }
                        Button { text: "+5%"; onClicked: discountValue = 100 < discountValue+5 ? 100 : discountValue + 5; }
                    }

                    Label {
                        text: qsTr("Price after discount:")
                        font.pixelSize: units.gu(4)
                    }

                    Label {
                        id: afterDiscount
                        text: toFixed(parseFloat(priceTextField.text.length > 0 ? priceTextField.text : 0)*(100-discountValue)/100, 2);
                        font.pixelSize: units.gu(4)
                    }
                }
            }
        }

        Bar {
            id: menuRect

            Row {
                anchors.fill: parent
                anchors.margins: units.gu(1)
                spacing: units.gu(1)

                Button {
                    id: aboutButton
                    text: qsTr("About")
                    onClicked: {
                        pageStack.push('PageAbout.qml');
                    }
                }

                Item {
                    width: parent.width - aboutButton.width - exitButton.width - parent.spacing*2
                    height: parent.height
                }

                Button {
                    id: exitButton
                    text: qsTr("Exit")
                    onClicked: {
                        Qt.quit()
                        }
                }
            }
        }
    }
}
