import QtQuick 1.1

Item {
    id: pageStackRoot
    property variant currentPage;
    property variant pages: [];

    onWidthChanged: {
        if (pages !== undefined) {
            for (var i = 0; i < pages.length; i++)
                pages[i].width = width;
        }
    }
    onHeightChanged: {
        if (pages !== undefined) {
            for (var i = 0; i < pages.length; i++)
                pages[i].height = height;
        }
    }

    function pop() {
        if (pages.length > 1) {
            var localPages = pages;
            var removedEl = localPages.pop();
            removedEl.state = "destroy";
            localPages[localPages.length-1].state = "active";
            pages = localPages;
        }
    }

    function push(page, properties) {
        var pageItem;
        if (typeof(page) == 'string') {
            var pageComponent = Qt.createComponent(page);
            if (pageComponent.status == Component.Ready) {
                var updated_properties = properties !== undefined ? properties : {};
                updated_properties.x = pageStackRoot.width;
                updated_properties.width = pageStackRoot.width;
                updated_properties.height = pageStackRoot.height;

                pageItem = pageComponent.createObject(pageStackRoot, updated_properties);
            }
            else if (pageComponent.status == Component.Error) {
                console.log('error: ' + pageComponent.errorString())
            }
        }
        else {
            pageItem = page;
            page.x = pageStackRoot.width;
            page.width = pageStackRoot.width;
            page.height = pageStackRoot.height;
        }

        pageItem.pageStack = pageStackRoot;
        if (pages.length > 0)
            pages[pages.length-1].state = "passive";
        pageItem.state = "active";

        var localPages = pages;
        localPages.push(pageItem)
        pages = localPages;
    }

    MouseArea {
        anchors.fill: parent
        onPressed: {
            // Let the mousePress events go to below items
            mouse.accepted = false;
            // Clicked item below the MouseArea gets the focus
            var selectedItem = pageStackRoot.childAt(mouse.x, mouse.y);
            if (!selectedItem) selectedItem = pageStackRoot;
            selectedItem.focus = true;
        }
    }
}
